@@ -5,7 +5,7 @@ import main
 from fileio.config import parse_config
 from log import setup_log, log
 
-def daemonize(squadron_dir, config_file, polltime, repo, loglevel):
+def daemonize(squadron_dir, config_file, polltime, repo):
     """
     Runs squadron every polltime minutes.
 
@@ -16,11 +16,10 @@ def daemonize(squadron_dir, config_file, polltime, repo, loglevel):
         repo -- source code for the squadron_dir for updating
         loglevel -- how much to log
     """
-
-    setup_log(loglevel)
-
-    parsed_config = parse_config(config_file)
-
+    log.debug('entering daemon.daemonize %s', 
+            [squadron_dir, config_file, polltime, repo])
+    parsed_config = parse_config(log, config_file)
+    print "Daemon is using loglevel: " + str(log.getEffectiveLevel())
     if not polltime:
         polltime = int(parsed_config['polltime'])
 
@@ -31,12 +30,17 @@ def daemonize(squadron_dir, config_file, polltime, repo, loglevel):
 
     while(True):
         git = repo.git
+        log.debug("Doing git checkout")
+        out = git.checkout('master')
+        log.debug('Git checkout returned: %s', out)
+        log.debug('Doing git pull --rebase')
+        out = git.pull('--rebase')
+        log.debug('Git pull returned: %s', out)
 
-        log.debug('Git checkout: ' + git.checkout('master'))
-        log.debug('Git pull: ' + git.pull('--rebase'))
-
-        if not main.go(squadron_dir, config_file=config_file):
+        ret = main.go(squadron_dir, config_file=config_file)
+        log.debug('main.go returned: %s', ret)
+        if ret:
             #TODO: Squadron sends bug to status API or some other remote server?
             log.error('Squadron had an error')
-
+        log.debug('daemon is sleeping: %s', polltime)
         time.sleep(polltime)
